@@ -1,23 +1,23 @@
 # Used in plot.mhmm through mHMMplotgrid
 
-HMMplot <- function(x, layout = "horizontal", pie = TRUE, 
-                    vertex.size = 40, vertex.label = "initial.probs", 
+HMMplot <- function(x, layout = "horizontal", pie = TRUE,
+                    vertex.size = 40, vertex.label = "initial.probs",
                     vertex.label.dist = "auto", vertex.label.pos = "bottom",
                     vertex.label.family = "sans",
-                    loops = FALSE, edge.curved = TRUE, edge.label = "auto", 
-                    edge.width = "auto", cex.edge.width = 1, 
+                    loops = FALSE, edge.curved = TRUE, edge.label = "auto",
+                    edge.width = "auto", cex.edge.width = 1,
                     edge.arrow.size = 1.5, edge.label.family = "sans",
                     label.signif = 2, label.scientific = FALSE, label.max.length = 6,
-                    trim = 1e-15, 
-                    combine.slices = 0.05, combined.slice.color = "white", 
+                    trim = 1e-15,
+                    combine.slices = 0.05, combined.slice.color = "white",
                     combined.slice.label = "others",
-                    withlegend = "bottom", ltext = NULL, legend.prop = 0.5, 
-                    cex.legend = 1, ncol.legend = "auto", cpal = "auto", 
+                    withlegend = "bottom", ltext = NULL, legend.prop = 0.5,
+                    cex.legend = 1, ncol.legend = "auto", cpal = "auto",
                     legend.pos = "center", main = "auto", ...){
-  
-  
+
+
   dots <- list(...)
-  
+
   labelprint <- function(z, labs) {
     if (labs == TRUE && (z > 0.001 || z == 0)) {
       labs <- FALSE
@@ -28,13 +28,13 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
       z <- prettyNum(signif(z, digits = label.signif), scientific = labs)
     }
   }
-  
+
   if (!is.matrix(layout) && !is.function(layout)) {
     if (!(layout %in% c("horizontal", "vertical"))) {
       stop("Argument layout only accepts numerical matrices, igraph layout functions, or strings \"horizontal\" and \"vertical\".")
     }
   }
-  
+
   if (!is.numeric(vertex.label.pos)) {
     choices <- c("bottom", "top", "left", "right")
     ind <- pmatch(vertex.label.pos, choices, duplicates.ok = TRUE)
@@ -43,7 +43,7 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
     }
     vertex.label.pos <- choices[ind]
   }
-  
+
   choices <- c(TRUE, FALSE, "bottom", "top", "left", "right")
   ind <- pmatch(withlegend, choices)
   if (is.na(ind)) {
@@ -51,21 +51,21 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
   }
   withlegend <- choices[ind]
   if (withlegend %in% c(TRUE, "auto")){
-    withlegend <- "right"
+    withlegend <- "bottom"
   }
-  
-  
+
+
   # Convert multichannel models to single-channel
   if (x$n_channels > 1) {
     x <- mc_to_sc(x)
   }
-  
+
   # No slices -> no legends needed
   if (pie == FALSE && withlegend != FALSE) {
     withlegend <- FALSE
   }
-  
-  
+
+
   # Positions of vertex labels
   if (!is.numeric(vertex.label.pos)) {
     vpos <- numeric(length(vertex.label.pos))
@@ -82,7 +82,7 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
     }
     vertex.label.pos <- vpos
   }
-  
+
   # Vertex labels
   if (length(vertex.label) == 1 && !is.na(vertex.label) && vertex.label != FALSE) {
     if (vertex.label == "initial.probs") {
@@ -94,7 +94,7 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
     warning("The length of the vector provided for the argument \"vertex.label\" does not match the number of hidden states.")
     vertex.label <- rep(vertex.label, length.out = length(x$state_names))
   }
-  
+
   # Vertex label distances
   if (is.character(vertex.label.dist)) {
     ind <- pmatch(vertex.label.dist, "auto")
@@ -106,12 +106,12 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
     warning("The length of the vector provided for the argument \"vertex.label.dist\" does not match the number of edges.")
     vertex.label.dist <- rep(vertex.label.dist, length.out = length(x$n_states))
   }
-  
-  
+
+
   # Trimming (remove small transition probablities from plot)
   transM <- x$transition_probs
   transM[transM < trim] <- 0
-  
+
   # Adjacency matrix (which edges to plot)
   edges <- transM
   edges[edges > 0] <- 1
@@ -119,14 +119,14 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
   if(!loops){
     diag(edges) <- 0
   }
-  
+
   # Vector of non-zero transition probabilities
   transitions <- transM
   if (loops == FALSE && length(transitions) > 1) {
     diag(transitions) <- 0
   }
   transitions <- t(transitions)[t(transitions) > 0]
-  
+
   # Edge labels
   if (!is.na(edge.label) && edge.label != FALSE) {
     if (length(edge.label) == 1 && (edge.label == "auto" || edge.label == TRUE)) {
@@ -136,8 +136,8 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
       edge.label <- rep(edge.label, length.out = length(transitions))
     }
   }
-  
-  
+
+
   # Edge widths
   if (is.character(edge.width)) {
     ind <- pmatch(edge.width, "auto")
@@ -149,10 +149,10 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
     warning("The length of the vector provided for the argument \"edge.width\" does not match the number of edges.")
     edge.width <- rep(edge.width, length.out = length(transitions))
   }
-  
+
   # Defining the graph structure
   g1 <- graph.adjacency(edges, mode = "directed")
-  
+
   # Layout of the graph
   if (is.function(layout)) {
     glayout <- layout(g1)
@@ -165,8 +165,8 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
       glayout <- layout_on_grid(g1, width = 1)
     }
   }
-  
-  
+
+
   # Colors for the (combinations of) observed states
   if (length(cpal) == 1 && cpal == "auto") {
     pie.colors <- attr(x$observations, "cpal")
@@ -181,7 +181,7 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
   if (withlegend != FALSE) {
     pie.colors.l <- pie.colors
   }
-  
+
   # Legend position and number of columns
   if (withlegend != FALSE && pie == TRUE) {
     if (!is.null(ltext)) {
@@ -193,7 +193,7 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
       ltext <- x$symbol_names
     }
   }
-  
+
   # Defining rescale, xlim, ylim if not given
   if (!is.matrix(layout) && !is.function(layout)) {
     if (layout == "horizontal") {
@@ -224,6 +224,11 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
       dots[["ylim"]] <- NULL
       dots[["rescale"]] <- NULL
     } else if (layout == "vertical") {
+      if (hasArg(rescale)) {
+        rescale <- dots$rescale
+      } else {
+        rescale <- FALSE
+      }
       if (hasArg(xlim)) {
         xlim <- dots$xlim
       } else {
@@ -247,13 +252,13 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
       dots[["rescale"]] <- NULL
     }
   }
-  
-  
+
+
   # Plotting graph
   if (pie == TRUE) {
     pie.values <- lapply(seq_len(nrow(transM)), function(i) x$emission_probs[i,])
     # If slices are combined
-    if (combine.slices > 0 && 
+    if (combine.slices > 0 &&
         !all(unlist(pie.values)[unlist(pie.values) > 0] > combine.slices)) {
       if (withlegend != FALSE) {
         pie.colors.l <- NULL
@@ -278,7 +283,7 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
         pie.colors.l <- c(unique(pie.colors.l), combined.slice.color)
       }
       if (ncol.legend == "auto") {
-        if (withlegend == "bottom" || withlegend == TRUE || withlegend == "top") {
+        if (withlegend == "bottom" || withlegend == "top") {
           ncol.legend <- ceiling(length(pie.colors) / 4)
         } else {
           ncol.legend <- 1
@@ -288,130 +293,130 @@ HMMplot <- function(x, layout = "horizontal", pie = TRUE,
       # Slices not combined
     } else {
       if (ncol.legend == "auto") {
-        if (withlegend == "bottom" || withlegend == TRUE || withlegend == "top") {
+        if (withlegend == "bottom" || withlegend == "top") {
           ncol.legend <- ceiling(ncol(x$emission_probs) / 4)
         } else {
           ncol.legend <- 1
         }
       }
     }
-    
-    if (!is.matrix(layout) && !is.function(layout) && 
+
+    if (!is.matrix(layout) && !is.function(layout) &&
          (layout == "horizontal" || layout == "vertical")) {
       if (length(dots) > 0) {
-        plotcall <- as.call(c(list(plot.igraph2, g1, layout = glayout, 
+        plotcall <- as.call(c(list(plot.igraph2, g1, layout = glayout,
                          vertex.shape = "pie", vertex.pie = pie.values,
                          vertex.pie.color = list(pie.colors),
-                         vertex.size = vertex.size, 
-                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist, 
+                         vertex.size = vertex.size,
+                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist,
                          vertex.label.degree = vertex.label.pos,
                          vertex.label.family = vertex.label.family,
-                         edge.curved = edge.curved, edge.width = edge.width, 
-                         edge.label = edge.label, 
-                         edge.label.family = edge.label.family, 
+                         edge.curved = edge.curved, edge.width = edge.width,
+                         edge.label = edge.label,
+                         edge.label.family = edge.label.family,
                          edge.arrow.size = edge.arrow.size,
                          xlim = xlim, ylim = ylim, rescale=rescale, main = main), dots))
       } else {
-        plotcall <- call("plot.igraph2", g1, layout = glayout, 
+        plotcall <- call("plot.igraph2", g1, layout = glayout,
                          vertex.shape = "pie", vertex.pie = pie.values,
                          vertex.pie.color = list(pie.colors),
-                         vertex.size = vertex.size, 
-                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist, 
+                         vertex.size = vertex.size,
+                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist,
                          vertex.label.degree = vertex.label.pos,
                          vertex.label.family = vertex.label.family,
-                         edge.curved = edge.curved, edge.width = edge.width, 
-                         edge.label = edge.label, 
-                         edge.label.family = edge.label.family, 
+                         edge.curved = edge.curved, edge.width = edge.width,
+                         edge.label = edge.label,
+                         edge.label.family = edge.label.family,
                          edge.arrow.size = edge.arrow.size,
                          xlim = xlim, ylim = ylim, rescale = rescale, main = main)
       }
     } else {
       if (length(dots) > 0) {
-        plotcall <- as.call(c(list(plot.igraph2, g1, layout = glayout, 
+        plotcall <- as.call(c(list(plot.igraph2, g1, layout = glayout,
                          vertex.shape = "pie", vertex.pie = pie.values,
                          vertex.pie.color = list(pie.colors),
-                         vertex.size = vertex.size, 
-                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist, 
+                         vertex.size = vertex.size,
+                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist,
                          vertex.label.degree = vertex.label.pos,
                          vertex.label.family = vertex.label.family,
-                         edge.curved = edge.curved, edge.width = edge.width, 
-                         edge.label = edge.label, 
+                         edge.curved = edge.curved, edge.width = edge.width,
+                         edge.label = edge.label,
                          edge.label.family = edge.label.family,
                          edge.arrow.size = edge.arrow.size, main = main), dots))
       } else {
-        plotcall <- call("plot.igraph2", g1, layout = glayout, 
+        plotcall <- call("plot.igraph2", g1, layout = glayout,
                          vertex.shape = "pie", vertex.pie = pie.values,
                          vertex.pie.color = list(pie.colors),
-                         vertex.size = vertex.size, 
-                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist, 
+                         vertex.size = vertex.size,
+                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist,
                          vertex.label.degree = vertex.label.pos,
                          vertex.label.family = vertex.label.family,
-                         edge.curved = edge.curved, edge.width = edge.width, 
-                         edge.label = edge.label, 
+                         edge.curved = edge.curved, edge.width = edge.width,
+                         edge.label = edge.label,
                          edge.label.family = edge.label.family,
                          edge.arrow.size = edge.arrow.size, main = main)
       }
     }
   } else {
-    if(!is.matrix(layout) && !is.function(layout) && 
+    if(!is.matrix(layout) && !is.function(layout) &&
          (layout == "horizontal" || layout == "vertical")){
       if (length(dots) > 0) {
-        plotcall <- as.call(c(list(plot.igraph2, g1, layout = glayout, 
-                         vertex.size = vertex.size, 
-                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist, 
+        plotcall <- as.call(c(list(plot.igraph2, g1, layout = glayout,
+                         vertex.size = vertex.size,
+                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist,
                          vertex.label.degree = vertex.label.pos,
                          vertex.label.family = vertex.label.family,
-                         edge.curved = edge.curved, edge.width = edge.width, 
-                         edge.label = edge.label, 
-                         edge.label.family = edge.label.family, 
+                         edge.curved = edge.curved, edge.width = edge.width,
+                         edge.label = edge.label,
+                         edge.label.family = edge.label.family,
                          xlim = xlim, ylim = ylim, rescale = rescale, main = main), dots))
       } else {
-        plotcall <- call("plot.igraph2", g1, layout = glayout, 
-                         vertex.size = vertex.size, 
-                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist, 
+        plotcall <- call("plot.igraph2", g1, layout = glayout,
+                         vertex.size = vertex.size,
+                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist,
                          vertex.label.degree = vertex.label.pos,
                          vertex.label.family = vertex.label.family,
-                         edge.curved = edge.curved, edge.width = edge.width, 
-                         edge.label = edge.label, 
-                         edge.label.family = edge.label.family, 
+                         edge.curved = edge.curved, edge.width = edge.width,
+                         edge.label = edge.label,
+                         edge.label.family = edge.label.family,
                          xlim = xlim, ylim = ylim, rescale = rescale, main = main)
       }
     } else {
       if(length(dots) > 0){
-        plotcall <- as.call(c(list(plot.igraph2, g1, layout = glayout, 
-                         vertex.size = vertex.size, 
-                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist, 
+        plotcall <- as.call(c(list(plot.igraph2, g1, layout = glayout,
+                         vertex.size = vertex.size,
+                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist,
                          vertex.label.degree = vertex.label.pos,
                          vertex.label.family = vertex.label.family,
-                         edge.curved = edge.curved, edge.width = edge.width, 
-                         edge.label = edge.label, 
+                         edge.curved = edge.curved, edge.width = edge.width,
+                         edge.label = edge.label,
                          edge.label.family = edge.label.family, main = main), dots))
       } else {
-        plotcall <- call("plot.igraph2", g1, layout = glayout, 
-                         vertex.size = vertex.size, 
-                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist, 
+        plotcall <- call("plot.igraph2", g1, layout = glayout,
+                         vertex.size = vertex.size,
+                         vertex.label = vertex.label, vertex.label.dist = vertex.label.dist,
                          vertex.label.degree = vertex.label.pos,
                          vertex.label.family = vertex.label.family,
-                         edge.curved = edge.curved, edge.width = edge.width, 
-                         edge.label = edge.label, 
+                         edge.curved = edge.curved, edge.width = edge.width,
+                         edge.label = edge.label,
                          edge.label.family = edge.label.family, main = main)
       }
     }
-  }  
-  
-  
+  }
+
+
   # Plotting legend
   if (withlegend != FALSE && pie == TRUE) {
-    legendcall <- call("seqlegend", seqdata = x$observations, cpal = pie.colors.l, ltext = ltext, 
+    legendcall <- call("seqlegend", seqdata = x$observations, cpal = pie.colors.l, ltext = ltext,
                        position = legend.pos, fontsize = cex.legend, ncol = ncol.legend,
                        with.missing = FALSE)
-    
+
   } else {
     legendcall <- NULL
   }
-  
-  
+
+
   return(list(plotcall = plotcall, legendcall = legendcall))
-  
+
   #graphics::layout(1)
-}
\ No newline at end of file
+}
