@@ -2,11 +2,17 @@
 #include "seqHMM.h"
 
 // [[Rcpp::export]]
-
-List EMx(arma::mat transition, arma::cube emission, arma::vec init,
-  const arma::ucube& obs, const arma::uvec& nSymbols, arma::mat coef, const arma::mat& X,
+List EMx(const arma::mat& transition_, const arma::cube& emission_, const arma::vec& init_,
+  const arma::ucube& obs, const arma::uvec& nSymbols, const arma::mat& coef_, const arma::mat& X,
   const arma::uvec& numberOfStates, int itermax, double tol, int trace, unsigned int threads) {
-
+  
+  // Make sure we don't alter the original vec/mat/cube
+  // needed for cube, in future maybe in other cases as well
+  arma::cube emission(emission_);
+  arma::mat transition(transition_);
+  arma::vec init(init_);
+  arma::mat coef(coef_);
+  
   coef.col(0).zeros();
   arma::mat weights = exp(X * coef).t();
   if (!weights.is_finite()) {
@@ -18,30 +24,7 @@ List EMx(arma::mat transition, arma::cube emission, arma::vec init,
   for (unsigned int k = 0; k < obs.n_slices; k++) {
     initk.col(k) = init % reparma(weights.col(k), numberOfStates);
   }
-  //
-  //   arma::cube alpha(emission.n_rows, obs.n_cols, obs.n_slices); //m,n,k
-  //   arma::cube beta(emission.n_rows, obs.n_cols, obs.n_slices); //m,n,k
-  //   arma::mat scales(obs.n_cols, obs.n_slices); //m,n,k
-  //
-  //   arma::sp_mat sp_trans(transition);
-  //   internalForwardx(sp_trans.t(), emission, initk, obs, alpha, scales, threads);
-  //   if(!scales.is_finite()) {
-  //     return List::create(Named("error") = 1);
-  //   }
-  //   internalBackwardx(sp_trans, emission, obs, beta, scales, threads);
-  //   if(!beta.is_finite()) {
-  //     return List::create(Named("error") = 2);
-  //   }
-  //   double min_sf = scales.min();
-  //   if (min_sf < 1e-150) {
-  //     Rcpp::warning("Smallest scaling factor was %e, results can be numerically unstable. ", min_sf);
-  //   }
-
-  // double sumlogLik = arma::accu(log(scales));
-  //
-  // if (trace > 0) {
-  //   Rcout << "Log-likelihood of initial model: " << sumlogLik << std::endl;
-  // }
+  
   //
   //  //EM-algorithm begins
   //
@@ -59,35 +42,33 @@ List EMx(arma::mat transition, arma::cube emission, arma::vec init,
     arma::cube gamma(emission.n_rows, emission.n_cols, emission.n_slices, arma::fill::zeros);
     arma::vec delta(emission.n_rows, arma::fill::zeros);
 
-    // for (unsigned int k = 0; k < obs.n_slices; k++) {
-    //   delta += alpha.slice(k).col(0) % beta.slice(k).col(0);
-    // }
     arma::mat bsi(emission.n_rows, obs.n_slices);
     sumlogLik_new = 0;
-    double min_sf = 1;
+    double max_sf = 1;
     unsigned int error_code = 0;
 
 #pragma omp parallel for if(obs.n_slices >= threads) schedule(static)  reduction(+:sumlogLik_new) num_threads(threads) \
-    default(none) shared(bsi, initk, transition, obs, emission, delta, ksii, gamma, nSymbols, error_code, min_sf)
+    default(none) shared(bsi, initk, transition, obs, emission, delta, ksii, gamma, nSymbols, error_code, max_sf)
       for (unsigned int k = 0; k < obs.n_slices; k++) {
+        
         arma::mat alpha(emission.n_rows, obs.n_cols); //m,n,k
         arma::vec scales(obs.n_cols);
         arma::sp_mat sp_trans(transition);
         uvForward(sp_trans.t(), emission, initk.col(k), obs.slice(k), alpha, scales);
         arma::mat beta(emission.n_rows, obs.n_cols); //m,n,k
         uvBackward(sp_trans, emission, obs.slice(k), beta, scales);
-        sumlogLik_new += arma::sum(log(scales));
+        sumlogLik_new -= arma::sum(log(scales));
 
         arma::mat ksii_k(emission.n_rows, emission.n_rows, arma::fill::zeros);
         arma::cube gamma_k(emission.n_rows, emission.n_cols, emission.n_slices, arma::fill::zeros);
         arma::vec delta_k(emission.n_rows);
-        delta_k = alpha.col(0) % beta.col(0);
+        delta_k = alpha.col(0) % beta.col(0) / scales(0);
 
         for (unsigned int i = 0; i < emission.n_rows; i++) {
           for (unsigned int j = 0; j < emission.n_rows; j++) {
             if (transition(i, j) > 0.0) {
               for (unsigned int t = 0; t < (obs.n_cols - 1); t++) {
-                double tmp = alpha(i, t) * transition(i, j) * beta(j, t + 1) / scales(t + 1);
+                double tmp = alpha(i, t) * transition(i, j) * beta(j, t + 1);
                 for (unsigned int r = 0; r < obs.n_rows; r++) {
                   tmp *= emission(j, obs(r, t + 1, k), r);
                 }
@@ -97,12 +78,12 @@ List EMx(arma::mat transition, arma::cube emission, arma::vec init,
           }
         }
         for (unsigned int r = 0; r < emission.n_slices; r++) {
-          for (int l = 0; l < nSymbols(r); l++) {
+          for (unsigned int l = 0; l < nSymbols(r); l++) {
             for (unsigned int i = 0; i < emission.n_rows; i++) {
               if (emission(i, l, r) > 0.0) {
                 for (unsigned int t = 0; t < obs.n_cols; t++) {
                   if (l == (obs(r, t, k))) {
-                    double tmp = alpha(i, t) * beta(i, t);
+                    double tmp = alpha(i, t) * beta(i, t) / scales(t);
                     gamma_k(i, l, r) += tmp;
                   }
                 }
@@ -111,7 +92,7 @@ List EMx(arma::mat transition, arma::cube emission, arma::vec init,
           }
         }
         for (unsigned int j = 0; j < emission.n_rows; j++) {
-          bsi(j, k) = beta(j, 0) / scales(0) * initk(j, k);
+          bsi(j, k) = beta(j, 0)  * initk(j, k);
         }
 #pragma omp critical
 {
@@ -121,7 +102,7 @@ List EMx(arma::mat transition, arma::cube emission, arma::vec init,
   if(!beta.is_finite()) {
     error_code = 2;
   }
-  min_sf = std::min(min_sf, scales.min());
+  max_sf = std::min(max_sf, scales.max());
   delta += delta_k;
   ksii += ksii_k;
   gamma += gamma_k;
@@ -133,8 +114,8 @@ List EMx(arma::mat transition, arma::cube emission, arma::vec init,
       if(error_code == 2) {
         return List::create(Named("error") = 2);
       }
-      if (min_sf < 1e-150) {
-        Rcpp::warning("Smallest scaling factor was %e, results can be numerically unstable.", min_sf);
+      if (max_sf > 1e150) {
+        Rcpp::warning("Largest scaling factor was %e, results can be numerically unstable.", max_sf);
       }
       change = (sumlogLik_new - sumlogLik) / (std::abs(sumlogLik) + 0.1);
       sumlogLik = sumlogLik_new;
