@@ -1,4 +1,4 @@
-// estimation of beta coefficients using log-space
+// estimation of gamma coefficients using log-space
 #include "seqHMM.h"
 
 unsigned int log_optCoef(arma::mat& weights, const arma::ucube& obs, const arma::cube& emission,
@@ -51,10 +51,10 @@ arma::vec log_gCoef(const arma::ucube& obs, const arma::cube& beta, const arma::
   arma::vec grad(q * (weights.n_rows - 1), arma::fill::zeros);
   double tmp;
   for (unsigned int jj = 1; jj < numberOfStates.n_elem; jj++) {
-    for (int k = 0; k < obs.n_slices; k++) {
+    for (unsigned int k = 0; k < obs.n_slices; k++) {
       for (unsigned int j = 0; j < emission.n_rows; j++) {
         tmp = 0.0;
-        for (int r = 0; r < obs.n_rows; r++) {
+        for (unsigned int r = 0; r < obs.n_rows; r++) {
           tmp += emission(j, obs(r, 0, k), r);
         }
         if ((j >= (cumsumstate(jj) - numberOfStates(jj))) & (j < cumsumstate(jj))) {
