@@ -6,7 +6,7 @@ List objectivex(const arma::mat& transition, const arma::cube& emission,
   const arma::vec& init, const arma::ucube& obs, const arma::umat& ANZ,
   const arma::ucube& BNZ, const arma::uvec& INZ, const arma::uvec& nSymbols,
   const arma::mat& coef, const arma::mat& X, arma::uvec& numberOfStates,
-  int threads) {
+  unsigned int threads) {
 
   unsigned int q = coef.n_rows;
   arma::vec grad(
@@ -25,36 +25,15 @@ List objectivex(const arma::mat& transition, const arma::cube& emission,
   for (unsigned int k = 0; k < obs.n_slices; k++) {
     initk.col(k) = init % reparma(weights.col(k), numberOfStates);
   }
-  //
-  //   arma::cube alpha(emission.n_rows, obs.n_cols, obs.n_slices); //m,n,k
-  //   arma::cube beta(emission.n_rows, obs.n_cols, obs.n_slices); //m,n,k
-  //   arma::mat scales(obs.n_cols, obs.n_slices); //m,n,k
-
-  // arma::sp_mat sp_trans(transition);
-  // internalForwardx(sp_trans.t(), emission, initk, obs, alpha, scales, threads);
-  // if (!scales.is_finite()) {
-  //   grad.fill(-arma::datum::inf);
-  //   return List::create(Named("objective") = arma::datum::inf, Named("gradient") = wrap(grad));
-  // }
-
-  // internalBackwardx(sp_trans, emission, obs, beta, scales, threads);
-  // if (!beta.is_finite()) {
-  //   grad.fill(-arma::datum::inf);
-  //   return List::create(Named("objective") = arma::datum::inf, Named("gradient") = wrap(grad));
-  // }
-
+  
   arma::uvec cumsumstate = arma::cumsum(numberOfStates);
-  //
-  //   arma::mat gradmat(
-  //       arma::accu(ANZ) + arma::accu(BNZ) + arma::accu(INZ) + (numberOfStates.n_elem- 1) * q,
-  //       obs.n_slices, arma::fill::zeros);
-
+  
   unsigned int error = 0;
   double ll = 0;
 #pragma omp parallel for if(obs.n_slices >= threads) schedule(static) reduction(+:ll) num_threads(threads)       \
   default(none) shared(q, grad, nSymbols, ANZ, BNZ, INZ,                                                         \
     numberOfStates, cumsumstate, obs, init, initk, X, weights, transition, emission, error)
-    for (int k = 0; k < obs.n_slices; k++) {
+    for (unsigned int k = 0; k < obs.n_slices; k++) {
       if (error == 0) {
         arma::mat alpha(emission.n_rows, obs.n_cols); //m,n
         arma::vec scales(obs.n_cols); //n
@@ -68,12 +47,12 @@ List objectivex(const arma::mat& transition, const arma::cube& emission,
         // transitionMatrix
         if (arma::accu(ANZ) > 0) {
 
-          for (int jj = 0; jj < numberOfStates.n_elem; jj++) {
+          for (unsigned int jj = 0; jj < numberOfStates.n_elem; jj++) {
             arma::vec gradArow(numberOfStates(jj));
             arma::mat gradA(numberOfStates(jj), numberOfStates(jj));
             int ind_jj = cumsumstate(jj) - numberOfStates(jj);
 
-            for (int i = 0; i < numberOfStates(jj); i++) {
+            for (unsigned int i = 0; i < numberOfStates(jj); i++) {
               arma::uvec ind = arma::find(ANZ.row(ind_jj + i).subvec(ind_jj, cumsumstate(jj) - 1));
 
               if (ind.n_elem > 0) {
@@ -83,13 +62,13 @@ List objectivex(const arma::mat& transition, const arma::cube& emission,
                 gradA.each_col() %= transition.row(ind_jj + i).subvec(ind_jj, cumsumstate(jj) - 1).t();
 
 
-                for (int j = 0; j < numberOfStates(jj); j++) {
+                for (unsigned int j = 0; j < numberOfStates(jj); j++) {
                   for (unsigned int t = 0; t < (obs.n_cols - 1); t++) {
                     double tmp = alpha(ind_jj + i, t);
                     for (unsigned int r = 0; r < obs.n_rows; r++) {
                       tmp *= emission(ind_jj + j, obs(r, t + 1, k), r);
                     }
-                    gradArow(j) += tmp * beta(ind_jj + j, t + 1) / scales(t + 1);
+                    gradArow(j) += tmp * beta(ind_jj + j, t + 1);
                   }
 
                 }
@@ -113,7 +92,7 @@ List objectivex(const arma::mat& transition, const arma::cube& emission,
                 gradB.eye();
                 gradB.each_row() -= emission.slice(r).row(i).subvec(0, nSymbols(r) - 1);
                 gradB.each_col() %= emission.slice(r).row(i).subvec(0, nSymbols(r) - 1).t();
-                for (int j = 0; j < nSymbols(r); j++) {
+                for (unsigned int j = 0; j < nSymbols(r); j++) {
                   if (obs(r, 0, k) == j) {
                     double tmp = initk(i, k);
                     for (unsigned int r2 = 0; r2 < obs.n_rows; r2++) {
@@ -121,11 +100,11 @@ List objectivex(const arma::mat& transition, const arma::cube& emission,
                         tmp *= emission(i, obs(r2, 0, k), r2);
                       }
                     }
-                    gradBrow(j) += tmp * beta(i, 0) / scales(0);
+                    gradBrow(j) += tmp * beta(i, 0);
                   }
                   for (unsigned int t = 0; t < (obs.n_cols - 1); t++) {
                     if (obs(r, t + 1, k) == j) {
-                      double tmp = beta(i, t + 1) / scales(t + 1);
+                      double tmp = beta(i, t + 1);
                       for (unsigned int r2 = 0; r2 < obs.n_rows; r2++) {
                         if (r2 != r) {
                           tmp *= emission(i, obs(r2, t + 1, k), r2);
@@ -145,18 +124,18 @@ List objectivex(const arma::mat& transition, const arma::cube& emission,
           }
         }
         if (arma::accu(INZ) > 0) {
-          for (int i = 0; i < numberOfStates.n_elem; i++) {
+          for (unsigned int i = 0; i < numberOfStates.n_elem; i++) {
             int ind_i = cumsumstate(i) - numberOfStates(i);
             arma::uvec ind = arma::find(
               INZ.subvec(ind_i, cumsumstate(i) - 1));
             if (ind.n_elem > 0) {
               arma::vec gradIrow(numberOfStates(i), arma::fill::zeros);
-              for (int j = 0; j < numberOfStates(i); j++) {
+              for (unsigned int j = 0; j < numberOfStates(i); j++) {
                 double tmp = weights(i, k);
                 for (unsigned int r = 0; r < obs.n_rows; r++) {
                   tmp *= emission(ind_i + j, obs(r, 0, k), r);
                 }
-                gradIrow(j) += tmp * beta(ind_i + j, 0) / scales(0);
+                gradIrow(j) += tmp * beta(ind_i + j, 0);
 
               }
               arma::mat gradI(numberOfStates(i), numberOfStates(i), arma::fill::zeros);
@@ -169,20 +148,20 @@ List objectivex(const arma::mat& transition, const arma::cube& emission,
             }
           }
         }
-        for (int jj = 1; jj < numberOfStates.n_elem; jj++) {
-          int ind_jj = (cumsumstate(jj) - numberOfStates(jj));
+        for (unsigned int jj = 1; jj < numberOfStates.n_elem; jj++) {
+          unsigned int ind_jj = (cumsumstate(jj) - numberOfStates(jj));
 
-          for (int j = 0; j < emission.n_rows; j++) {
+          for (unsigned int j = 0; j < emission.n_rows; j++) {
             double tmp = 1.0;
             for (unsigned int r = 0; r < obs.n_rows; r++) {
               tmp *= emission(j, obs(r, 0, k), r);
             }
             if ((j >= ind_jj) & (j < cumsumstate(jj))) {
               grad_k.subvec(countgrad + q * (jj - 1), countgrad + q * jj - 1) += tmp
-              * beta(j, 0) / scales(0) * initk(j, k) * X.row(k).t() * (1.0 - weights(jj, k));
+              * beta(j, 0) * initk(j, k) * X.row(k).t() * (1.0 - weights(jj, k));
             } else {
               grad_k.subvec(countgrad + q * (jj - 1), countgrad + q * jj - 1) -= tmp
-              * beta(j, 0) / scales(0) * initk(j, k) * X.row(k).t() * weights(jj, k);
+              * beta(j, 0) * initk(j, k) * X.row(k).t() * weights(jj, k);
             }
           }
 
@@ -191,7 +170,7 @@ List objectivex(const arma::mat& transition, const arma::cube& emission,
 #pragma omp atomic
           error++;
         } else {
-          ll += arma::sum(log(scales));
+          ll -= arma::sum(log(scales));
 #pragma omp critical
           grad += grad_k;
         }
