@@ -3,15 +3,9 @@
 
 // [[Rcpp::export]]
 
-List viterbix(const arma::mat& transition, NumericVector emissionArray,
-    const arma::vec& init, IntegerVector obsArray, const arma::mat& coef, const arma::mat& X,
-    const arma::ivec& numberOfStates) {
-
-  IntegerVector eDims = emissionArray.attr("dim"); //m,p,r
-  IntegerVector oDims = obsArray.attr("dim"); //k,n,r
-
-  arma::cube emission(emissionArray.begin(), eDims[0], eDims[1], eDims[2], false, true);
-  arma::icube obs(obsArray.begin(), oDims[0], oDims[1], oDims[2], false, true);
+List viterbix(const arma::mat& transition, const arma::cube& emission,
+    const arma::vec& init, const arma::ucube& obs, const arma::mat& coef, const arma::mat& X,
+    const arma::uvec& numberOfStates) {
 
   arma::umat q(obs.n_slices, obs.n_cols);
   arma::vec logp(obs.n_slices);
@@ -42,8 +36,8 @@ List viterbix(const arma::mat& transition, NumericVector emissionArray,
       }
     }
 
-    delta.col(obs.n_cols - 1).max(q(k, obs.n_cols - 1));
-
+    //delta.col(obs.n_cols - 1).max(q(k, obs.n_cols - 1));
+    q(k, obs.n_cols - 1) = delta.col(obs.n_cols - 1).index_max();
     for (int t = (obs.n_cols - 2); t >= 0; t--) {
       q(k, t) = phi(q(k, t + 1), t + 1);
     }
